==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SubjectRulesReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectRulesReviewBuilder extends io.fabric8.openshift.api.model.SubjectRulesReviewFluentImpl<io.fabric8.openshift.api.model.SubjectRulesReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SubjectRulesReview,io.fabric8.openshift.api.model.SubjectRulesReviewBuilder>{
  public SubjectRulesReviewBuilder() {
    this(false);
  }
  public SubjectRulesReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectRulesReview(), validationEnabled);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectRulesReview(), validationEnabled);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReview instance) {
    this(fluent, instance, false);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReview instance) {
    this(instance,false);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SubjectRulesReview build() {
    SubjectRulesReview buildable = new SubjectRulesReview(fluent.getApiVersion(),fluent.getKind(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectRulesReviewBuilder that = (SubjectRulesReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.4-sources.jar: io/fabric8/openshift/api/model/SubjectRulesReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectRulesReviewBuilder extends io.fabric8.openshift.api.model.SubjectRulesReviewFluentImpl<io.fabric8.openshift.api.model.SubjectRulesReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SubjectRulesReview,io.fabric8.openshift.api.model.SubjectRulesReviewBuilder>{
  public SubjectRulesReviewBuilder() {
    this(false);
  }
  public SubjectRulesReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectRulesReview(), validationEnabled);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectRulesReview(), validationEnabled);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReview instance) {
    this(fluent, instance, false);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReview instance) {
    this(instance,false);
  }
  public SubjectRulesReviewBuilder(io.fabric8.openshift.api.model.SubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SubjectRulesReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SubjectRulesReview build() {
    SubjectRulesReview buildable = new SubjectRulesReview(fluent.getApiVersion(),fluent.getKind(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectRulesReviewBuilder that = (SubjectRulesReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
